@@ -10,7 +10,7 @@ import sys
 
 from collections import namedtuple
 from mesh_client import MeshClient, MeshError, default_ssl_opts, CombineStreams, LOCAL_MOCK_ENDPOINT
-from mesh_client.mock_server import MockMeshApplication, MockMeshChunkRetryApplication
+from mesh_client.mock_server import MockMeshApplication, MockMeshChunkRetryApplication, SlowMockMeshApplication
 from six.moves.urllib.error import HTTPError
 
 alice_mailbox = 'alice'
@@ -269,6 +269,21 @@ class EndpointTest(TestCase):
             self.assertEqual(hand_shook, b"hello")
 
 
+class TimeoutTest(TestCase):
+    def test_timeout(self):
+        with SlowMockMeshApplication() as mock_app:
+            endpoint = LOCAL_MOCK_ENDPOINT._replace(url=mock_app.uri)
+            client = MeshClient(
+                endpoint,
+                alice_mailbox,
+                alice_password,
+                max_chunk_size=5,
+                timeout=0.5)
+            with self.assertRaises(requests.exceptions.Timeout):
+                client.list_messages()
+
+
+
 class MeshChunkRetryClientTest(TestCase):
     def run(self, result=None):
         self.chunk_retry_call_counts = {}
